@@ -812,9 +812,9 @@ $printthis
 	close TOFILE;
 	close RETLIST;
 	close RETBLOCK;
-	#say $tee "INEXIT \@retcases " . dump( @retcases ); 
-	#say $tee "\@retstruct " . dump( @retstruct ); 
-	#say $tee "\@notecases " . dump( @notecases ); 
+	say $tee "INEXIT \@retcases " . dump( @retcases ); 
+	say $tee "\@retstruct " . dump( @retstruct ); 
+	say $tee "\@notecases " . dump( @notecases ); 
 	return ( \@retcases, \@retstruct, \@notecases );
 }	# END SUB RETRIEVE
 
