@@ -89,12 +89,11 @@ sub sim    # This function launch the simulations in ESP-r
 	
 	#open( OUTFILE, ">>$outfile" ) or die "Can't open $outfile: $!"; 
 	open( TOFILE, ">>$tofile" ) or die "Can't open $tofile: $!"; 
-	say  "\nNow in Sim::OPT::Sim.\n";
-	say TOFILE "\n#Now in Sim::OPT::Sim.\n";
+	say $tee "\nNow in Sim::OPT::Sim.\n";
 	
 	%dowhat = %main::dowhat;
 
-	%simtitles = %main::simtitles; say "dumpINSIM(\%simtitles): " . dump(%simtitles);
+	%simtitles = %main::simtitles; #say "dumpINSIM(\%simtitles): " . dump(%simtitles);
 	%retrievedata = %main::retrievedata;
 	@keepcolumns = @main::keepcolumns;
 	@weights = @main::weights;
@@ -146,7 +145,7 @@ sub sim    # This function launch the simulations in ESP-r
 	#if ( fileno (MORPHLIST) 
 
 	my @container;
-	say TOFILE "dump(\@instances): " . dump(@instances);
+	#say TOFILE "dump(\@instances): " . dump(@instances);
 	my $countinstance = 0;
 	foreach my $instance (@instances)
 	{
@@ -157,7 +156,7 @@ sub sim    # This function launch the simulations in ESP-r
 		my @winneritems = @{ $d{winneritems} }; #say TOFILE "dumpIN( \@winneritems) " . dump(@winneritems);
 		my $countvar = $d{countvar}; #say TOFILE "dump(\$countvar): " . dump($countvar);
 		my $countstep = $d{countstep}; #say TOFILE "dump(\$countstep): " . dump($countstep);						
-		my $to = $d{to}; say TOFILE "dump(\$to): " . dump($to);
+		my $to = $d{to}; #say TOFILE "dump(\$to): " . dump($to);
 		my $origin = $d{origin}; #say TOFILE "dump(\$origin): " . dump($origin);
 		my @uplift = @{ $d{uplift} }; #say TOFILE "dump(\@uplift): " . dump(@uplift);
 		#eval($getparshere);
@@ -188,16 +187,16 @@ sub sim    # This function launch the simulations in ESP-r
 		#	print SIMLIST "$to\n";
 		#}
 		
-		my $numberof_simtools = scalar ( keys %{ $dowhat{simtools} } ); say TOFILE "\$numberof_simtools " . dump( $numberof_simtools );
+		my $numberof_simtools = scalar ( keys %{ $dowhat{simtools} } ); #say TOFILE "\$numberof_simtools " . dump( $numberof_simtools );
 		my $simelt = $to;
 		
 		my $counttool = 1;
 		while ( $counttool <= $numberof_simtools )
 		{	
-			my $skip = $vals{$countvar}{$counttool}{skip}; say TOFILE "dumpinsim(\$skip): " . dump($skip);
+			my $skip = $vals{$countvar}{$counttool}{skip}; #say TOFILE "dumpinsim(\$skip): " . dump($skip);
 			if ( not ( eval ( $skipsim{$counttool} )))
 			{
-				my $tooltype = $dowhat{simtools}{$counttool}; say TOFILE "\$tooltype " . dump( $tooltype );
+				my $tooltype = $dowhat{simtools}{$counttool}; #say TOFILE "\$tooltype " . dump( $tooltype );
 				
 				if ( $tooltype eq "esp-r" )
 				{	
@@ -211,20 +210,20 @@ sub sim    # This function launch the simulations in ESP-r
 						$launchline = "-file $simelt\\cfg\\$fileconfig -mode script";
 					}
 					
-					say TOFILE "dump(\%simtitles): " . dump( %simtitles ); 
-					say TOFILE "dump(\$simtitles{\$counttool}): " . dump( $simtitles{$counttool} ); 
-					say TOFILE "dump(\@{ \$simtitles{\$counttool}): " . dump( @{ $simtitles{$counttool} } ); 	
+					#say TOFILE "dump(\%simtitles): " . dump( %simtitles ); 
+					#say TOFILE "dump(\$simtitles{\$counttool}): " . dump( $simtitles{$counttool} ); 
+					#say TOFILE "dump(\@{ \$simtitles{\$counttool}): " . dump( @{ $simtitles{$counttool} } ); 	
 					my $countsim = 0;		
 					foreach my $simtitle_ref ( @{ $simtitles{$counttool} } )
 					{
-						my $date_to_sim = $simtitle_ref->[0]; say TOFILE "dump(\$date_to_sim ): " . dump( $date_to_sim ); 
-						my $begin = $simtitle_ref->[1]; say TOFILE "dump(\$begin): " . dump($begin); 
-						my $end = $simtitle_ref->[2]; say TOFILE "dump(\$end): " . dump($end); 
-						my $before = $simtitle_ref->[3]; say TOFILE "dump(\$before): " . dump($before); 
-						my $step = $simtitle_ref->[4]; say TOFILE "dump(\$step): " . dump($step); 
+						my $date_to_sim = $simtitle_ref->[0]; #say TOFILE "dump(\$date_to_sim ): " . dump( $date_to_sim ); 
+						my $begin = $simtitle_ref->[1]; #say TOFILE "dump(\$begin): " . dump($begin); 
+						my $end = $simtitle_ref->[2]; #say TOFILE "dump(\$end): " . dump($end); 
+						my $before = $simtitle_ref->[3]; #say TOFILE "dump(\$before): " . dump($before); 
+						my $step = $simtitle_ref->[4]; #say TOFILE "dump(\$step): " . dump($step); 
 						
-						my $resfile = "$simelt-$date_to_sim-$tooltype.res"; say TOFILE "dump(\$resfile): " . dump($resfile); 
-						my $flfile = "$simelt-$date_to_sim-$tooltype.fl"; say TOFILE "dump(\$flfile): " . dump($flfile); 
+						my $resfile = "$simelt-$date_to_sim-$tooltype.res"; #say TOFILE "dump(\$resfile): " . dump($resfile); 
+						my $flfile = "$simelt-$date_to_sim-$tooltype.fl"; #say TOFILE "dump(\$flfile): " . dump($flfile); 
 
 						#if ( fileno (SIMLIST) )
 						#if (not (-e $simlist ) )
@@ -354,38 +353,38 @@ $printthis
 					my $countsim = 0;			
 					foreach my $simtitle_ref ( @{ $simtitles{$counttool} } )
 					{
-						my $date_to_sim = $simtitle_ref->[0]; say TOFILE "dump(\$date_to_sim ): " . dump( $date_to_sim ); 
-						my $begin = $simtitle_ref->[1]; say TOFILE "dump(\$begin): " . dump($begin); 
-						my $end = $simtitle_ref->[2]; say TOFILE "dump(\$end): " . dump($end); 
-						my $before = $simtitle_ref->[3]; say TOFILE "dump(\$before): " . dump($before); 
-						my $step = $simtitle_ref->[4]; say TOFILE "dump(\$step): " . dump($step); 
+						my $date_to_sim = $simtitle_ref->[0]; #say TOFILE "dump(\$date_to_sim ): " . dump( $date_to_sim ); 
+						my $begin = $simtitle_ref->[1]; #say TOFILE "dump(\$begin): " . dump($begin); 
+						my $end = $simtitle_ref->[2]; #say TOFILE "dump(\$end): " . dump($end); 
+						my $before = $simtitle_ref->[3]; #say TOFILE "dump(\$before): " . dump($before); 
+						my $step = $simtitle_ref->[4]; #say TOFILE "dump(\$step): " . dump($step); 
 						 
-						my $epw = $simtitle_ref->[5]; say TOFILE "dump(\$epw ): " . dump( $epw ); 
-						my $epwfile = $mypath . "/" . $epw; say TOFILE"\$epwfile " . dump( $epwfile );
-						my $epdir = $simtitle_ref->[6]; say TOFILE "dump(\$epdir ): " . dump( $epdir ); 
-						my $epoldfile = $simtitle_ref->[7]; say TOFILE "dump(\$epoldfile ): " . dump( $epoldfile ); 
-						my $epnewfragment = $simtitle_ref->[8]; say TOFILE "dump(\$epnewfragment ): " . dump( $epnewfragment );  
-						my $outputdir = $simtitle_ref->[9]; say TOFILE "dump(\$outputdir ): " . dump( $outputdir ); 
-						my $modfiletype = $simtitle_ref->[10]; say TOFILE "dump(\$modfiletype ): " . dump( $modfiletype ); 
-						my $resfiletype = $simtitle_ref->[11]; say TOFILE "dump(\$resfiletype ): " . dump( $resfiletype ); 
-						my $epoldpath = $to . $epdir . "/" . $epoldfile; say TOFILE "dump(\$epoldpath ): " . dump( $epoldpath ); 
+						my $epw = $simtitle_ref->[5]; #say TOFILE "dump(\$epw ): " . dump( $epw ); 
+						my $epwfile = $mypath . "/" . $epw; #say TOFILE"\$epwfile " . dump( $epwfile );
+						my $epdir = $simtitle_ref->[6]; #say TOFILE "dump(\$epdir ): " . dump( $epdir ); 
+						my $epoldfile = $simtitle_ref->[7]; #say TOFILE "dump(\$epoldfile ): " . dump( $epoldfile ); 
+						my $epnewfragment = $simtitle_ref->[8]; #say TOFILE "dump(\$epnewfragment ): " . dump( $epnewfragment );  
+						my $outputdir = $simtitle_ref->[9]; #say TOFILE "dump(\$outputdir ): " . dump( $outputdir ); 
+						my $modfiletype = $simtitle_ref->[10]; #say TOFILE "dump(\$modfiletype ): " . dump( $modfiletype ); 
+						my $resfiletype = $simtitle_ref->[11]; #say TOFILE "dump(\$resfiletype ): " . dump( $resfiletype ); 
+						my $epoldpath = $to . $epdir . "/" . $epoldfile; #say TOFILE "dump(\$epoldpath ): " . dump( $epoldpath ); 
 						my $tempname = $to;
-						$tempname =~ s/$mypath\/// ; say TOFILE "dump(\$tempname ): " . dump( $tempname ); 
-						my $epnewfile = $tempname . $epnewfragment . "$modfiletype"; say TOFILE "dump(\$epnewfile ): " . dump( $epnewfile ); 
-						my $epresroot = $tempname . $epnewfragment ; say TOFILE "dump(\$epnewfile ): " . dump( $epnewfile ); 
+						$tempname =~ s/$mypath\/// ; #say TOFILE "dump(\$tempname ): " . dump( $tempname ); 
+						my $epnewfile = $tempname . $epnewfragment . "$modfiletype"; #say TOFILE "dump(\$epnewfile ): " . dump( $epnewfile ); 
+						my $epresroot = $tempname . $epnewfragment ; #say TOFILE "dump(\$epnewfile ): " . dump( $epnewfile ); 
 						
 						my $epnewpath;
 						unless ( ( "$^O" eq "MSWin32" ) or ( "$^O" eq "MSWin64" ) ) 
 						{ 
-							$epnewpath = $to . $epdir . "/" . $epnewfile; say TOFILE "dump(\$epnewpath ): " . dump( $epnewpath ); 
+							$epnewpath = $to . $epdir . "/" . $epnewfile; #say TOFILE "dump(\$epnewpath ): " . dump( $epnewpath ); 
 						}
 						else
 						{ 
-							$epnewpath = $to . $epdir . "\\" . $epnewfile; say TOFILE "dump(\$epnewpath ): " . dump( $epnewpath ); 
+							$epnewpath = $to . $epdir . "\\" . $epnewfile; #say TOFILE "dump(\$epnewpath ): " . dump( $epnewpath ); 
 						}
 						
 						my @simdos = @{ $simtitle_ref };
-						my @changes = @simdos[ 12..$#simdos ]; say TOFILE "dump(\@changes ): " . dump( @changes ); 
+						my @changes = @simdos[ 12..$#simdos ]; #say TOFILE "dump(\@changes ): " . dump( @changes ); 
 						if ( $tooltype eq "energyplus" ) # RESTORES DEFAULTS FOR ENERGYPLUS
 						{
 							unless ( ( "$^O" eq "MSWin32" ) or ( "$^O" eq "MSWin64" ) ) 
@@ -540,8 +539,8 @@ $printthis
 	}
 	close SIMLIST;
 	close SIMBLOCK;
-	say TOFILE "dump(\@simcases ): " . dump( @simcases ); 
-	say TOFILE "dump(\@simstruct ): " . dump( @simstruct ); 
+	#say TOFILE "dump(\@simcases ): " . dump( @simcases ); 
+	#say TOFILE "dump(\@simstruct ): " . dump( @simstruct ); 
 	return ( \@simcases, \@simstruct );
 	close TOFILE;
 	close OUTFILE;
